@@ -6,15 +6,20 @@ use warnings;
 use base 'Exporter';
 
 use Test::More;
+use AnyEvent
 
 our @EXPORT = qw( ev_loop );
 
 sub ev_loop {
-  my $cv = shift;
+  my $sub = shift;
+
+  my $cv = AnyEvent->condvar();
+
+  $sub->( $cv );
 
   my $timer;
   $timer = AnyEvent->timer(
-    after => 5,
+    after => 3,
     cb => sub {
       diag( 'Emergency exit from event loop. Test failed' );
       $cv->send();
